@@ -1,7 +1,11 @@
+( cd opt/kde/share/doc/HTML/ro/khelpcenter/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
 ( cd opt/kde/share/doc/HTML/ro/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ro/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
 ( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ro/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kioslave ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kioslave ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf qpl-license.html )
@@ -24,6 +28,8 @@
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 9.png )
@@ -54,6 +60,8 @@
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1.png )
@@ -66,8 +74,12 @@
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf 10.png )
@@ -84,6 +96,10 @@
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/ro/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf kde-localised.css.template )
@@ -94,5 +110,39 @@
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/ro/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/ro/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/kinfocenter ; rm -rf common )
-( cd opt/kde/share/doc/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/..//common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ro/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/ro/common common )
